@@ -159,9 +159,6 @@ class get_change_log:
 
         return report_df
 
-    def bld_df_from_search_result(self, search_l):
-        return self.glob.bld_df_from_search_result(conn=self.conn, search_l=search_l)
-
     def obj_id_from_df_l(self, report_df,obj_col_ind,type_col_ind):
         obj_l=[]
         for index, obj in report_df.iterrows():
@@ -287,4 +284,6 @@ class searches:
         return list(self.glob.used_by_obj_rec_l(conn=conn,
                                                 project_id=project_id,
                                                 obj_l=obj_id_l)
-                    )
\ No newline at end of file
+                    )
+    def bld_df_from_search_result(self, conn,search_l):
+        return self.glob.bld_df_from_search_result(conn=conn, search_l=search_l)
\ No newline at end of file
